/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ;
typedef struct tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
struct tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ {
NIM_BOOL somethingTodo;
NI inFinally;
};
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg {
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* wasMovedLocs;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
NIM_BOOL hasReturn;
NIM_BOOL hasBreak;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* label;
tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* parent;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
typedef NU tyArray__VqSA39cBDWnwnJySTumCdjw[8];
struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ {
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* next;
NI key;
tyArray__VqSA39cBDWnwnJySTumCdjw bits;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, analyse__jOfoc43pObYwIqMht3S5cQ)(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ* c, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, wasMovedDestroyPair__r1oPArmROvniJq69cCoSOGg)(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ* c, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, NIM_BOOL strictSymEquality);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__7hiIf9cX1T4l9amfLkdHBowAast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, del__TgBXLpGAm0rF5SZ3bkKUbg_2)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, NI i);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__qAerQ9bftuf70QDk42UIFXg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn);
N_LIB_PRIVATE N_NIMCALL(void, returnStmt__SSIrm1pgTv2yTkvGbSgcFA)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, invalidateWasMoved__x5Yckax9bc1iZUDx9cUqh4zQ)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x);
N_LIB_PRIVATE N_NIMCALL(void, nestedBlock__LMlukjLSCl79cO9aGIp31srQ)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* parent, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* Result);
static N_INLINE(void, mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* parent, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* this_0);
N_LIB_PRIVATE N_NIMCALL(void, intersect__3Xssrm8SXzjhY9cuH9aXecOg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** summary, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* branch);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, wasMovedTarget__J9cJ9baeNU6Q4c9csxmJQKElQ)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* matches, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* branch, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* moveTarget);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(void, breakStmt__OZiUZ59bk9a9ccLb4VqcRy9aVA)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, opt__9bdcyKeBj1CNkV04ReZhgog)(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* parent, NI parentPos);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);

/* section: NIM_merge_DATA */
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
STRING_LITERAL(TM__zdBS9bxu9aeb3QPAJFgGx9cyQ_2, "=destroy", 8);
STRING_LITERAL(TM__zdBS9bxu9aeb3QPAJFgGx9cyQ_3, "=sink", 5);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__7hiIf9cX1T4l9amfLkdHBowAast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, wasMovedDestroyPair__r1oPArmROvniJq69cCoSOGg)(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ* c, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* d) {
	NI i;
	i = ((NI) 0);
	{
		while (1) {
			NI T3_;
			T3_ = ((*b).wasMovedLocs ? (*b).wasMovedLocs->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
				NIM_BOOL T8_;
				T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T6_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*(*b).wasMovedLocs->data[i])._kind_6.sons->data[((NI) 1)]);
				T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T7_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*d)._kind_6.sons->data[((NI) 1)]);
				T8_ = (NIM_BOOL)0;
				T8_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA(T6_, T7_, NIM_TRUE);
				if (!T8_) goto LA9_;
				(*(*b).wasMovedLocs->data[i]).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 0)) & 31);
				(*c).somethingTodo = NIM_TRUE;
				(*d).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 0)) & 31);
				del__TgBXLpGAm0rF5SZ3bkKUbg_2((&(*b).wasMovedLocs), ((NI) (i)));
			}
			goto LA4_;
			LA9_: ;
			{
				i += ((NI) 1);
			}
			LA4_: ;
		} LA2: ;
	}
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, returnStmt__SSIrm1pgTv2yTkvGbSgcFA)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b) {
	tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* it;
	(*b).hasReturn = NIM_TRUE;
	it = b;
	{
		while (1) {
			if (!!((it == ((tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg*) NIM_NIL)))) goto LA2;
			unsureAsgnRef((void**) (&(*it).wasMovedLocs), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*it).wasMovedLocs)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 0)));
			it = (*it).parent;
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, invalidateWasMoved__x5Yckax9bc1iZUDx9cUqh4zQ)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x) {
	NI i;
	i = ((NI) 0);
	{
		while (1) {
			NI T3_;
			T3_ = ((*c).wasMovedLocs ? (*c).wasMovedLocs->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
				NIM_BOOL T7_;
				T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T6_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*(*c).wasMovedLocs->data[i])._kind_6.sons->data[((NI) 1)]);
				T7_ = (NIM_BOOL)0;
				T7_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA(T6_, x, NIM_TRUE);
				if (!T7_) goto LA8_;
				del__TgBXLpGAm0rF5SZ3bkKUbg_2((&(*c).wasMovedLocs), ((NI) (i)));
			}
			goto LA4_;
			LA8_: ;
			{
				i += ((NI) 1);
			}
			LA4_: ;
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, nestedBlock__LMlukjLSCl79cO9aGIp31srQ)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* parent, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* Result) {
	unsureAsgnRef((void**)&(*Result).wasMovedLocs, NIM_NIL);
	(*Result).kind = 0;
	(*Result).hasReturn = 0;
	(*Result).hasBreak = 0;
	unsureAsgnRef((void**)&(*Result).label, NIM_NIL);
	(*Result).parent = NIM_NIL;
	unsureAsgnRef((void**) (&(*Result).wasMovedLocs), NIM_NIL);
	(*Result).kind = kind;
	(*Result).hasReturn = NIM_FALSE;
	(*Result).hasBreak = NIM_FALSE;
	unsureAsgnRef((void**) (&(*Result).label), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	(*Result).parent = parent;
}
static N_INLINE(void, mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* parent, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* this_0) {
	{
		if (!(*this_0).hasReturn) goto LA3_;
		unsureAsgnRef((void**) (&(*parent).wasMovedLocs), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*parent).wasMovedLocs)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 0)));
		(*parent).hasReturn = NIM_TRUE;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, wasMovedTarget__J9cJ9baeNU6Q4c9csxmJQKElQ)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* matches, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* branch, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* moveTarget) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (branch ? branch->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
					NIM_BOOL T8_;
					T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T7_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*branch->data[i])._kind_6.sons->data[((NI) 1)]);
					T8_ = (NIM_BOOL)0;
					T8_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA(T7_, moveTarget, NIM_TRUE);
					if (!T8_) goto LA9_;
					result = NIM_TRUE;
					incl__jENnK9c9bPE73pKmo2vYjpqg(matches, i);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, intersect__3Xssrm8SXzjhY9cuH9aXecOg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** summary, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* branch) {
	NI i;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg matches;
	i = ((NI) 0);
	nimZeroMem((void*)(&matches), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&matches));
	{
		while (1) {
			NI T3_;
			T3_ = ((*summary) ? (*summary)->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
				NIM_BOOL T7_;
				T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T6_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*(*summary)->data[i])._kind_6.sons->data[((NI) 1)]);
				T7_ = (NIM_BOOL)0;
				T7_ = wasMovedTarget__J9cJ9baeNU6Q4c9csxmJQKElQ((&matches), branch, T6_);
				if (!T7_) goto LA8_;
				i += ((NI) 1);
			}
			goto LA4_;
			LA8_: ;
			{
				del__TgBXLpGAm0rF5SZ3bkKUbg_2(summary, ((NI) (i)));
			}
			LA4_: ;
		} LA2: ;
	}
	{
		NI m;
		m = (NI)0;
		{
			if (!(matches.elems <= ((NI) 34))) goto LA14_;
			{
				NI i_2;
				NI i_3;
				i_2 = (NI)0;
				i_3 = ((NI) 0);
				{
					while (1) {
						NI T19_;
						if (!(i_3 < matches.elems)) goto LA18;
						i_2 = i_3;
						m = matches.a[(i_2)- 0];
						unsureAsgnRef((void**) (&(*summary)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*summary)), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
						T19_ = (*summary)->Sup.len++;
						asgnRef((void**) (&(*summary)->data[T19_]), branch->data[m]);
						i_3 += ((NI) 1);
					} LA18: ;
				}
			}
		}
		goto LA12_;
		LA14_: ;
		{
			tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* r;
			r = matches.head;
			{
				while (1) {
					NI i_4;
					if (!!((r == ((tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ*) NIM_NIL)))) goto LA22;
					i_4 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_4 <= ((NI) 7))) goto LA24;
							w = (*r).bits[(i_4)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA26;
									{
										NI T31_;
										NI T32_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA29_;
										T31_ = (NI)0;
										T31_ = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((NI)((NU64)(i_4) << (NU64)(((NI) 6))), j);
										m = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T31_);
										unsureAsgnRef((void**) (&(*summary)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*summary)), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
										T32_ = (*summary)->Sup.len++;
										asgnRef((void**) (&(*summary)->data[T32_]), branch->data[m]);
									}
									LA29_: ;
									j += ((NI) 1);
									w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
								} LA26: ;
							}
							i_4 += ((NI) 1);
						} LA24: ;
					}
					r = (*r).next;
				} LA22: ;
			}
		}
		LA12_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, breakStmt__OZiUZ59bk9a9ccLb4VqcRy9aVA)(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* it;
	it = b;
	{
		while (1) {
			if (!!((it == ((tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg*) NIM_NIL)))) goto LA2;
			unsureAsgnRef((void**) (&(*it).wasMovedLocs), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*it).wasMovedLocs)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 0)));
			(*it).hasBreak = NIM_TRUE;
			{
				if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA5_;
				{
					if (!((*it).label == (*n)._kind_4.sym)) goto LA9_;
					goto LA1;
				}
				LA9_: ;
			}
			goto LA3_;
			LA5_: ;
			{
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127))) goto LA14_;
					goto LA1;
				}
				LA14_: ;
			}
			LA3_: ;
			it = (*it).parent;
		} LA2: ;
	} LA1: ;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, analyse__jOfoc43pObYwIqMht3S5cQ)(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ* c, tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		NIM_BOOL special;
		NIM_BOOL reverse;
		special = NIM_FALSE;
		reverse = NIM_FALSE;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA4_;
			s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				NI T10_;
				if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 149))) goto LA8_;
				unsureAsgnRef((void**) (&(*b).wasMovedLocs), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*b).wasMovedLocs), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
				T10_ = (*b).wasMovedLocs->Sup.len++;
				asgnRef((void**) (&(*b).wasMovedLocs->data[T10_]), n);
				special = NIM_TRUE;
			}
			goto LA6_;
			LA8_: ;
			{
				if (!eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__zdBS9bxu9aeb3QPAJFgGx9cyQ_2))) goto LA12_;
				{
					NIM_BOOL T16_;
					NIM_BOOL T18_;
					T16_ = (NIM_BOOL)0;
					T16_ = (((NI) 0) < (*c).inFinally);
					if (!(T16_)) goto LA17_;
					T18_ = (NIM_BOOL)0;
					T18_ = (*b).hasReturn;
					if (T18_) goto LA19_;
					T18_ = (*b).hasBreak;
					LA19_: ;
					T16_ = T18_;
					LA17_: ;
					if (!T16_) goto LA20_;
				}
				goto LA14_;
				LA20_: ;
				{
					wasMovedDestroyPair__r1oPArmROvniJq69cCoSOGg(c, b, n);
				}
				LA14_: ;
				special = NIM_TRUE;
			}
			goto LA6_;
			LA12_: ;
			{
				if (!eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__zdBS9bxu9aeb3QPAJFgGx9cyQ_3))) goto LA24_;
				reverse = NIM_TRUE;
			}
			goto LA6_;
			LA24_: ;
			LA6_: ;
		}
		LA4_: ;
		{
			if (!!(special)) goto LA28_;
			{
				if (!!(reverse)) goto LA32_;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA36;
							i = i_2;
							analyse__jOfoc43pObYwIqMht3S5cQ(c, b, (*n)._kind_6.sons->data[i]);
							i_2 += ((NI) 1);
						} LA36: ;
					}
				}
			}
			goto LA30_;
			LA32_: ;
			{
				{
					NI i_3;
					NI colontmp__2;
					NI T39_;
					NI res;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					T39_ = (NI)0;
					T39_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					colontmp__2 = (NI)(T39_ - ((NI) 1));
					res = colontmp__2;
					{
						while (1) {
							if (!(((NI) 0) <= res)) goto LA41;
							i_3 = res;
							analyse__jOfoc43pObYwIqMht3S5cQ(c, b, (*n)._kind_6.sons->data[i_3]);
							res -= ((NI) 1);
						} LA41: ;
					}
				}
			}
			LA30_: ;
			{
				NIM_BOOL T44_;
				T44_ = (NIM_BOOL)0;
				T44_ = canRaise__qAerQ9bftuf70QDk42UIFXg_2((*n)._kind_6.sons->data[((NI) 0)]);
				if (!T44_) goto LA45_;
				returnStmt__SSIrm1pgTv2yTkvGbSgcFA(b);
			}
			LA45_: ;
		}
		LA28_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		invalidateWasMoved__x5Yckax9bc1iZUDx9cUqh4zQ(b, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 121):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 158):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		analyse__jOfoc43pObYwIqMht3S5cQ(c, b, (*n)._kind_6.sons->data[((NI) 1)]);
		analyse__jOfoc43pObYwIqMht3S5cQ(c, b, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		NIM_BOOL isExhaustive;
		NI T51_;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* wasMovedSet;
		T51_ = (NI)0;
		T51_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		isExhaustive = ((*(*n)._kind_6.sons->data[(NI)(T51_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88) || (*(*n)._kind_6.sons->data[(NI)(T51_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 50));
		wasMovedSet = NIM_NIL;
		{
			NI i_4;
			NI colontmp__3;
			NI i_5;
			i_4 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_5 = ((NI) 0);
			{
				while (1) {
					tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg branch;
					if (!(i_5 < colontmp__3)) goto LA54;
					i_4 = i_5;
					nimZeroMem((void*)(&branch), sizeof(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg));
					nestedBlock__LMlukjLSCl79cO9aGIp31srQ(b, (*(*n)._kind_6.sons->data[i_4]).kind, (&branch));
					analyse__jOfoc43pObYwIqMht3S5cQ(c, (&branch), (*n)._kind_6.sons->data[i_4]);
					mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer(b, (&branch));
					{
						if (!isExhaustive) goto LA57_;
						{
							if (!(i_4 == ((NI) 0))) goto LA61_;
							wasMovedSet = branch.wasMovedLocs;
							branch.wasMovedLocs = NIM_NIL;
						}
						goto LA59_;
						LA61_: ;
						{
							intersect__3Xssrm8SXzjhY9cuH9aXecOg((&wasMovedSet), branch.wasMovedLocs);
						}
						LA59_: ;
					}
					LA57_: ;
					i_5 += ((NI) 1);
				} LA54: ;
			}
		}
		{
			NI i_6;
			NI colontmp__4;
			NI T65_;
			NI i_7;
			i_6 = (NI)0;
			colontmp__4 = (NI)0;
			T65_ = (wasMovedSet ? wasMovedSet->Sup.len : 0);
			colontmp__4 = T65_;
			i_7 = ((NI) 0);
			{
				while (1) {
					NI T68_;
					if (!(i_7 < colontmp__4)) goto LA67;
					i_6 = i_7;
					unsureAsgnRef((void**) (&(*b).wasMovedLocs), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*b).wasMovedLocs), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
					T68_ = (*b).wasMovedLocs->Sup.len++;
					asgnRef((void**) (&(*b).wasMovedLocs->data[T68_]), wasMovedSet->data[i_6]);
					i_7 += ((NI) 1);
				} LA67: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		NIM_BOOL isExhaustive_2;
		NIM_BOOL T70_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T71_;
		NI T73_;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* wasMovedSet_2;
		T70_ = (NIM_BOOL)0;
		T71_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T71_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710672));
		T70_ = !(((IL64(1031060586496) &((NU64)1<<((NU)((*T71_).kind)&63U)))!=0));
		if (T70_) goto LA72_;
		T73_ = (NI)0;
		T73_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T70_ = ((*(*n)._kind_6.sons->data[(NI)(T73_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88));
		LA72_: ;
		isExhaustive_2 = T70_;
		analyse__jOfoc43pObYwIqMht3S5cQ(c, b, (*n)._kind_6.sons->data[((NI) 0)]);
		wasMovedSet_2 = NIM_NIL;
		{
			NI i_8;
			NI colontmp__5;
			NI i_9;
			i_8 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_9 = ((NI) 1);
			{
				while (1) {
					tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg branch_2;
					if (!(i_9 < colontmp__5)) goto LA76;
					i_8 = i_9;
					nimZeroMem((void*)(&branch_2), sizeof(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg));
					nestedBlock__LMlukjLSCl79cO9aGIp31srQ(b, (*(*n)._kind_6.sons->data[i_8]).kind, (&branch_2));
					analyse__jOfoc43pObYwIqMht3S5cQ(c, (&branch_2), (*n)._kind_6.sons->data[i_8]);
					mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer(b, (&branch_2));
					{
						if (!isExhaustive_2) goto LA79_;
						{
							if (!(i_8 == ((NI) 1))) goto LA83_;
							wasMovedSet_2 = branch_2.wasMovedLocs;
							branch_2.wasMovedLocs = NIM_NIL;
						}
						goto LA81_;
						LA83_: ;
						{
							intersect__3Xssrm8SXzjhY9cuH9aXecOg((&wasMovedSet_2), branch_2.wasMovedLocs);
						}
						LA81_: ;
					}
					LA79_: ;
					i_9 += ((NI) 1);
				} LA76: ;
			}
		}
		{
			NI i_10;
			NI colontmp__6;
			NI T87_;
			NI i_11;
			i_10 = (NI)0;
			colontmp__6 = (NI)0;
			T87_ = (wasMovedSet_2 ? wasMovedSet_2->Sup.len : 0);
			colontmp__6 = T87_;
			i_11 = ((NI) 0);
			{
				while (1) {
					NI T90_;
					if (!(i_11 < colontmp__6)) goto LA89;
					i_10 = i_11;
					unsureAsgnRef((void**) (&(*b).wasMovedLocs), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*b).wasMovedLocs), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
					T90_ = (*b).wasMovedLocs->Sup.len++;
					asgnRef((void**) (&(*b).wasMovedLocs->data[T90_]), wasMovedSet_2->data[i_10]);
					i_11 += ((NI) 1);
				} LA89: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	{
		{
			NI i_12;
			NI colontmp__7;
			NI i_13;
			i_12 = (NI)0;
			colontmp__7 = (NI)0;
			colontmp__7 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_13 = ((NI) 0);
			{
				while (1) {
					tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg tryBody;
					if (!(i_13 < colontmp__7)) goto LA94;
					i_12 = i_13;
					nimZeroMem((void*)(&tryBody), sizeof(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg));
					nestedBlock__LMlukjLSCl79cO9aGIp31srQ(b, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106), (&tryBody));
					analyse__jOfoc43pObYwIqMht3S5cQ(c, (&tryBody), (*n)._kind_6.sons->data[i_12]);
					mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer(b, (&tryBody));
					i_13 += ((NI) 1);
				} LA94: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg loopBody;
		analyse__jOfoc43pObYwIqMht3S5cQ(c, b, (*n)._kind_6.sons->data[((NI) 0)]);
		nimZeroMem((void*)(&loopBody), sizeof(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg));
		nestedBlock__LMlukjLSCl79cO9aGIp31srQ(b, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96), (&loopBody));
		analyse__jOfoc43pObYwIqMht3S5cQ(c, (&loopBody), (*n)._kind_6.sons->data[((NI) 1)]);
		mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer(b, (&loopBody));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg blockBody;
		nimZeroMem((void*)(&blockBody), sizeof(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg));
		nestedBlock__LMlukjLSCl79cO9aGIp31srQ(b, (*n).kind, (&blockBody));
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA99_;
			blockBody.label = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		LA99_: ;
		analyse__jOfoc43pObYwIqMht3S5cQ(c, (&blockBody), (*n)._kind_6.sons->data[((NI) 1)]);
		mergeBasicBlockInfo__3rphkeLFzSBBMNkLcMgNKQoptimizer(b, (&blockBody));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		breakStmt__OZiUZ59bk9a9ccLb4VqcRy9aVA(b, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
			child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_14;
				NI colontmp__8;
				NI i_15;
				i_14 = (NI)0;
				colontmp__8 = (NI)0;
				colontmp__8 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_15 = ((NI) 0);
				{
					while (1) {
						if (!(i_15 < colontmp__8)) goto LA106;
						i_14 = i_15;
						child = (*n)._kind_6.sons->data[i_14];
						analyse__jOfoc43pObYwIqMht3S5cQ(c, b, child);
						i_15 += ((NI) 1);
					} LA106: ;
				}
			}
		}
		returnStmt__SSIrm1pgTv2yTkvGbSgcFA(b);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107):
	{
		(*c).inFinally += ((NI) 1);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child_2;
			child_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_16;
				NI colontmp__9;
				NI i_17;
				i_16 = (NI)0;
				colontmp__9 = (NI)0;
				colontmp__9 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_17 = ((NI) 0);
				{
					while (1) {
						if (!(i_17 < colontmp__9)) goto LA111;
						i_16 = i_17;
						child_2 = (*n)._kind_6.sons->data[i_16];
						analyse__jOfoc43pObYwIqMht3S5cQ(c, b, child_2);
						i_17 += ((NI) 1);
					} LA111: ;
				}
			}
		}
		(*c).inFinally -= ((NI) 1);
	}
	break;
	default:
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child_3;
			child_3 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_18;
				NI colontmp__10;
				NI i_19;
				i_18 = (NI)0;
				colontmp__10 = (NI)0;
				colontmp__10 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_19 = ((NI) 0);
				{
					while (1) {
						if (!(i_19 < colontmp__10)) goto LA116;
						i_18 = i_19;
						child_3 = (*n)._kind_6.sons->data[i_18];
						analyse__jOfoc43pObYwIqMht3S5cQ(c, b, child_3);
						i_19 += ((NI) 1);
					} LA116: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, opt__9bdcyKeBj1CNkV04ReZhgog)(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* parent, NI parentPos) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 0))&31U)))!=0)) goto LA4_;
			asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info));
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* xX60gensym39_;
			xX60gensym39_ = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
			{
				NI iX60gensym39_;
				NI colontmp_;
				NI i;
				iX60gensym39_ = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i = ((NI) 0);
				{
					while (1) {
						if (!(i < colontmp_)) goto LA9;
						iX60gensym39_ = i;
						opt__9bdcyKeBj1CNkV04ReZhgog(c, (*n)._kind_6.sons->data[iX60gensym39_], xX60gensym39_, iX60gensym39_);
						i += ((NI) 1);
					} LA9: ;
				}
			}
			asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), xX60gensym39_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 121):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 158):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
		asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), n);
	}
	break;
	default:
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* xX60gensym43_;
		xX60gensym43_ = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
		{
			NI iX60gensym43_;
			NI colontmp__2;
			NI i_2;
			iX60gensym43_ = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp__2)) goto LA14;
					iX60gensym43_ = i_2;
					opt__9bdcyKeBj1CNkV04ReZhgog(c, (*n)._kind_6.sons->data[iX60gensym43_], xX60gensym43_, iX60gensym43_);
					i_2 += ((NI) 1);
				} LA14: ;
			}
		}
		asgnRef((void**) (&(*parent)._kind_6.sons->data[parentPos]), xX60gensym43_);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, optimize__VCZeNpSpiHRRAv9coeudyIg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ c;
	tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg b;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&c), sizeof(tyObject_Con__QbIMFB4loKCf0ZFA2SwcWQ));
	nimZeroMem((void*)(&b), sizeof(tyObject_BasicBlock__BqJRpBqlD9bKSJMY28pMcmg));
	analyse__jOfoc43pObYwIqMht3S5cQ((&c), (&b), n);
	{
		if (!c.somethingTodo) goto LA3_;
		result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					opt__9bdcyKeBj1CNkV04ReZhgog(c, (*n)._kind_6.sons->data[i], result, i);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
